@@ -20,7 +20,7 @@ from django.utils.encoding import smart_str
 
 from sentry.app import env
 from sentry.conf import settings
-from sentry.exceptions import InvalidInterface, InvalidData, InvalidTimestamp
+from sentry.exceptions import InvalidTimestamp
 from sentry.models import Project, ProjectKey, TeamMember, Team
 from sentry.plugins import plugins
 from sentry.tasks.store import store_event
@@ -32,7 +32,7 @@ from sentry.utils.queue import maybe_delay
 logger = logging.getLogger('sentry.coreapi.errors')
 
 MAX_CULPRIT_LENGTH = 200
-MAX_MESSAGE_LENGTH = 1000
+MAX_MESSAGE_LENGTH = 5000
 
 INTERFACE_ALIASES = {
     'exception': 'sentry.interfaces.Exception',
@@ -86,6 +86,26 @@ class APITimestampExpired(APIError):
     http_status = 410
 
 
+def client_metadata(client=None, exception=None, tags=None, extra=None):
+    if not extra:
+        extra = {}
+    if not tags:
+        tags = {}
+
+    extra['client'] = client
+    extra['request'] = env.request
+    extra['tags'] = tags
+
+    tags['client'] = client
+    if exception:
+        tags['exc_type'] = type(exception).__name__
+
+    result = {'extra': extra}
+    if exception:
+        result['exc_info'] = True
+    return result
+
+
 def extract_auth_vars(request):
     if request.META.get('HTTP_X_SENTRY_AUTH', '').startswith('Sentry'):
         return parse_auth_header(request.META['HTTP_X_SENTRY_AUTH'])
@@ -212,7 +232,7 @@ def decode_and_decompress_data(encoded_data):
     except Exception, e:
         # This error should be caught as it suggests that there's a
         # bug somewhere in the client's code.
-        logger.exception('Bad data received')
+        logger.info(e, **client_metadata(exception=e))
         raise APIForbidden('Bad data decoding request (%s, %s)' % (
             e.__class__.__name__, e))
 
@@ -223,7 +243,7 @@ def safely_load_json_string(json_string):
     except Exception, e:
         # This error should be caught as it suggests that there's a
         # bug somewhere in the client's code.
-        logger.exception('Bad data received')
+        logger.info(e, **client_metadata(exception=e))
         raise APIForbidden('Bad data reconstructing object (%s, %s)' % (
             e.__class__.__name__, e))
 
@@ -231,11 +251,13 @@ def safely_load_json_string(json_string):
     return dict((smart_str(k), v) for k, v in obj.iteritems())
 
 
-def ensure_valid_project_id(desired_project, data):
+def ensure_valid_project_id(desired_project, data, client=None):
     # Confirm they're using either the master key, or their specified project
     # matches with the signed project.
     if desired_project and data.get('project'):
         if str(data.get('project')) not in [str(desired_project.id), desired_project.slug]:
+            logger.info('Project ID mismatch: %s != %s', desired_project.id, desired_project.slug,
+                **client_metadata(client))
             raise APIForbidden('Invalid credentials')
         data['project'] = desired_project.id
     elif not desired_project:
@@ -270,73 +292,86 @@ def process_data_timestamp(data):
 
 
 def validate_data(project, data, client=None):
-    ensure_valid_project_id(project, data)
+    ensure_valid_project_id(project, data, client=client)
 
     if not data.get('message'):
         data['message'] = '<no message value>'
     elif len(data['message']) > MAX_MESSAGE_LENGTH:
-        raise InvalidData('Value \'message\' is too long. Input is %d chars, max is %s.' % (
-            len(data['message']), MAX_MESSAGE_LENGTH))
+        logger.error('Truncated value for message due to length (%d chars)', len(data['message']),
+            **client_metadata(client))
+        data['message'] = data['message'][:MAX_MESSAGE_LENGTH]
 
-    if data.get('culprit') and len(data['culprit']) > 200:
-        raise InvalidData('Value \'culprit\' is too long. Input is %d chars, max is %s.' % (
-            len(data['culprit']), MAX_CULPRIT_LENGTH))
+    if data.get('culprit') and len(data['culprit']) > MAX_CULPRIT_LENGTH:
+        logger.error('Truncated value for culprit due to length (%d chars)', len(data['culprit']),
+            **client_metadata(client))
+        data['culprit'] = data['culprit'][:MAX_CULPRIT_LENGTH]
 
     if not data.get('event_id'):
         data['event_id'] = uuid.uuid4().hex
-    elif len(data['event_id']) > 32:
-        raise InvalidData('Invalid value for \'event_id\': must be a 32 character identifier')
+    if len(data['event_id']) > 32:
+        logger.error('Discarded value for event_id due to length (%d chars)', len(data['event_id']),
+            **client_metadata(client))
+        data['event_id'] = uuid.uuid4().hex
 
     if 'timestamp' in data:
         try:
             process_data_timestamp(data)
-        except InvalidTimestamp:
+        except InvalidTimestamp, e:
             # Log the error, remove the timestamp, and continue
-            logger.info('Client %r passed an invalid value for timestamp %r',
-                client or '<unknown client>', data['timestamp'], extra={'request': env.request})
+            logger.info('Discarded invalid value for timestamp: %r', data['timestamp'],
+                **client_metadata(client, exception=e))
             del data['timestamp']
 
     if data.get('modules') and type(data['modules']) != dict:
-        raise InvalidData('Invalid type for \'modules\': must be a mapping')
+        logger.error('Discardied invalid type for modules: %s', type(data['modules']),
+            **client_metadata(client))
+        del data['modules']
 
     for k in data.keys():
         if k in RESERVED_FIELDS:
             continue
 
         if not data[k]:
-            logger.info('Ignoring empty interface %r passed by client %r',
-                k, client or '<unknown client>', extra={'request': env.request})
+            logger.info('Ignored empty interface value: %s', k, **client_metadata(client))
             del data[k]
             continue
 
         import_path = INTERFACE_ALIASES.get(k, k)
 
         if '.' not in import_path:
-            logger.info('Ignoring unknown attribute %r passed by client %r',
-                k, client or '<unknown client>', extra={'request': env.request})
+            logger.warning('Ignored unknown attribute: %s', k, **client_metadata(client))
             del data[k]
             continue
 
         try:
             interface = import_string(import_path)
         except (ImportError, AttributeError), e:
-            raise InvalidInterface('%r is not a valid interface name: %s' % (k, e))
+            logger.warning('Invalid unknown attribute: %s', k, **client_metadata(client, exception=e))
+            del data[k]
+            continue
 
+        value = data.pop(k)
         try:
-            data[import_path] = interface(**data.pop(k)).serialize()
+            inst = interface(**value)
+            inst.validate()
+            data[import_path] = inst.serialize()
         except Exception, e:
-            logger.error('Client %r passed an invalid value for interface %r',
-                client or '<unknown client>',
-                interface, exc_info=True, extra={'request': env.request})
-            raise InvalidData('Unable to validate interface, %r: %s' % (k, e))
+            if isinstance(e, AssertionError):
+                log = logger.warning
+            else:
+                log = logger.error
+            log('Discarded invalid value for interface: %s', k,
+                **client_metadata(client, exception=e, extra={'value': value}))
 
     level = data.get('level') or settings.DEFAULT_LOG_LEVEL
     if isinstance(level, basestring) and not level.isdigit():
         # assume it's something like 'warning'
         try:
             data['level'] = settings.LOG_LEVEL_REVERSE_MAP[level]
-        except KeyError:
-            raise InvalidData('Invalid logging level specified: %r' % level)
+        except KeyError, e:
+            logger.warning('Discarded invalid logger value: %s', level, **client_metadata(client, exception=e))
+            data['level'] = settings.LOG_LEVEL_REVERSE_MAP.get(settings.DEFAULT_LOG_LEVEL,
+                settings.DEFAULT_LOG_LEVEL)
 
     return data
 
