@@ -13,7 +13,8 @@ import itertools
 import urlparse
 
 from pygments import highlight
-from pygments.lexers import get_lexer_for_filename, TextLexer, ClassNotFound
+# from pygments.lexers import get_lexer_for_filename, TextLexer, ClassNotFound
+from pygments.lexers import TextLexer
 from pygments.formatters import HtmlFormatter
 
 from django.http import QueryDict
@@ -61,10 +62,11 @@ def get_context(lineno, context_line, pre_context=None, post_context=None, filen
         filename = 'index.html'
 
     if format:
-        try:
-            lexer = get_lexer_for_filename(filename)
-        except ClassNotFound:
-            lexer = TextLexer()
+        # try:
+        #     lexer = get_lexer_for_filename(filename)
+        # except ClassNotFound:
+        #     lexer = TextLexer()
+        lexer = TextLexer()
 
         formatter = HtmlFormatter()
 
@@ -99,6 +101,9 @@ class Interface(object):
     def __getstate__(self):
         return self.serialize()
 
+    def validate(self):
+        pass
+
     def unserialize(self, data):
         return data
 
@@ -111,10 +116,10 @@ class Interface(object):
     def get_hash(self):
         return []
 
-    def to_html(self, event):
+    def to_html(self, event, is_public=False, **kwargs):
         return ''
 
-    def to_string(self, event):
+    def to_string(self, event, is_public=False, **kwargs):
         return ''
 
     def get_slug(self):
@@ -162,11 +167,12 @@ class Message(Interface):
     """
 
     def __init__(self, message, params=()):
-        assert len(message) <= 1000
-
         self.message = message
         self.params = params
 
+    def validate(self):
+        assert len(self.message) <= 5000
+
     def serialize(self):
         return {
             'message': self.message,
@@ -298,9 +304,6 @@ class Stacktrace(Interface):
             if 'abs_path' in frame and 'filename' not in frame:
                 frame['filename'] = frame.pop('abs_path', None)
 
-            # ensure we've got the correct required values
-            assert frame.get('filename') or frame.get('function') or frame.get('module')
-
             # lineno should be an int
             if 'lineno' in frame:
                 if frame['lineno'] is None:
@@ -326,6 +329,11 @@ class Stacktrace(Interface):
                     frame['abs_path'] = abs_path
                     frame['filename'] = urlparts.path
 
+    def validate(self):
+        for frame in self.frames:
+            # ensure we've got the correct required values
+            assert frame.get('filename') or frame.get('function') or frame.get('module')
+
     def serialize(self):
         return {
             'frames': self.frames,
@@ -375,7 +383,7 @@ class Stacktrace(Interface):
 
         return newest_first
 
-    def to_html(self, event):
+    def to_html(self, event, is_public=False, **kwargs):
         if not self.frames:
             return ''
 
@@ -396,12 +404,6 @@ class Stacktrace(Interface):
                 context = []
                 start_lineno = None
 
-            context_vars = []
-            if frame.get('vars'):
-                context_vars = frame['vars']
-            else:
-                context_vars = []
-
             if frame.get('lineno') is not None:
                 lineno = int(frame['lineno'])
             else:
@@ -416,9 +418,10 @@ class Stacktrace(Interface):
                 'start_lineno': start_lineno,
                 'lineno': lineno,
                 'context': context,
-                'vars': context_vars,
                 'in_app': in_app,
             }
+            if not is_public:
+                frame_data['vars'] = frame.get('vars') or []
 
             if event.platform == 'javascript' and frame.get('data'):
                 data = frame['data']
@@ -442,6 +445,7 @@ class Stacktrace(Interface):
             frames = frames[::-1]
 
         return render_to_string('sentry/partial/interfaces/stacktrace.html', {
+            'is_public': is_public,
             'newest_first': newest_first,
             'system_frames': system_frames,
             'event': event,
@@ -449,7 +453,7 @@ class Stacktrace(Interface):
             'stacktrace': self.get_traceback(event, newest_first=newest_first),
         })
 
-    def to_string(self, event):
+    def to_string(self, event, is_public=False, **kwargs):
         return self.get_stacktrace(event, system_frames=False, max_frames=5)
 
     def get_stacktrace(self, event, system_frames=True, newest_first=None, max_frames=None):
@@ -554,12 +558,13 @@ class Exception(Interface):
     def get_hash(self):
         return filter(bool, [self.type, self.value])
 
-    def to_html(self, event):
+    def to_html(self, event, is_public=False, **kwargs):
         last_frame = None
         interface = event.interfaces.get('sentry.interfaces.Stacktrace')
         if interface is not None and interface.frames:
             last_frame = interface.frames[-1]
         return render_to_string('sentry/partial/interfaces/exception.html', {
+            'is_public': is_public,
             'event': event,
             'exception_value': self.value,
             'exception_type': self.type,
@@ -661,7 +666,7 @@ class Http(Interface):
             'env': self.env,
         }
 
-    def to_string(self, event):
+    def to_string(self, event, is_public=False, **kwargs):
         return render_to_string('sentry/partial/interfaces/http.txt', {
             'event': event,
             'full_url': '?'.join(filter(bool, [self.url, self.query_string])),
@@ -682,7 +687,7 @@ class Http(Interface):
         else:
             return True, value
 
-    def to_html(self, event):
+    def to_html(self, event, is_public=False, **kwargs):
         data = self.data
         data_is_dict = False
         headers_is_dict, headers = self._to_dict(self.headers)
@@ -690,10 +695,8 @@ class Http(Interface):
         if headers_is_dict and headers.get('Content-Type') == 'application/x-www-form-urlencoded':
             data_is_dict, data = self._to_dict(data)
 
-        # It's kind of silly we store this twice
-        cookies_is_dict, cookies = self._to_dict(self.cookies or headers.pop('Cookie', {}))
-
-        return render_to_string('sentry/partial/interfaces/http.html', {
+        context = {
+            'is_public': is_public,
             'event': event,
             'full_url': '?'.join(filter(bool, [self.url, self.query_string])),
             'url': self.url,
@@ -701,12 +704,20 @@ class Http(Interface):
             'data': data,
             'data_is_dict': data_is_dict,
             'query_string': self.query_string,
-            'cookies': cookies,
-            'cookies_is_dict': cookies_is_dict,
             'headers': self.headers,
             'headers_is_dict': headers_is_dict,
-            'env': self.env,
-        })
+        }
+        if not is_public:
+            # It's kind of silly we store this twice
+            cookies_is_dict, cookies = self._to_dict(self.cookies)
+
+            context.update({
+                'cookies': cookies,
+                'cookies_is_dict': cookies_is_dict,
+                'env': self.env,
+            })
+
+        return render_to_string('sentry/partial/interfaces/http.html', context)
 
     def get_title(self):
         return _('Request')
@@ -765,7 +776,7 @@ class Template(Interface):
     def get_hash(self):
         return [self.filename, self.context_line]
 
-    def to_string(self, event):
+    def to_string(self, event, is_public=False, **kwargs):
         context = get_context(
             lineno=self.lineno,
             context_line=self.context_line,
@@ -782,7 +793,7 @@ class Template(Interface):
 
         return '\n'.join(result)
 
-    def to_html(self, event):
+    def to_html(self, event, is_public=False, **kwargs):
         context = get_context(
             lineno=self.lineno,
             context_line=self.context_line,
@@ -800,6 +811,7 @@ class Template(Interface):
             'start_lineno': context[0][0],
             'context': context,
             'template': self.get_traceback(event, context),
+            'is_public': is_public,
         })
 
     def get_traceback(self, event, context):
@@ -852,8 +864,9 @@ class User(Interface):
     def get_hash(self):
         return []
 
-    def to_html(self, event):
+    def to_html(self, event, is_public=False, **kwargs):
         return render_to_string('sentry/partial/interfaces/user.html', {
+            'is_public': is_public,
             'event': event,
             'user_id': self.id,
             'user_username': self.username,
