@@ -44,6 +44,7 @@ from sentry.signals import buffer_incr_complete, regression_signal
 from sentry.utils import cached_property, MockDjangoRequest
 from sentry.utils.models import Model, GzippedDictField, update
 from sentry.utils.imports import import_string
+from sentry.utils.safe import safe_execute
 from sentry.utils.strings import truncatechars
 
 __all__ = ('Event', 'Group', 'Project', 'SearchDocument')
@@ -122,6 +123,9 @@ class Team(Model):
             return self.owner.email.split('@', 1)[0]
         return self.owner.username
 
+    def __unicode__(self):
+        return u'%s' % self.name
+
 
 class TeamMember(Model):
     """
@@ -184,7 +188,7 @@ class Project(Model):
     def delete(self):
         # This hadles cascades properly
         # TODO: this doesnt clean up the index
-        for model in (Event, Group, FilterValue, MessageFilterValue, MessageCountByMinute):
+        for model in (Event, Group, FilterValue, GroupTag, GroupCountByMinute):
             model.objects.filter(project=self).delete()
         super(Project, self).delete()
 
@@ -202,13 +206,13 @@ class Project(Model):
                 )
             except Group.DoesNotExist:
                 group.update(project=project)
-                for model in (Event, MessageFilterValue, MessageCountByMinute):
+                for model in (Event, GroupTag, GroupCountByMinute):
                     model.objects.filter(project=self, group=group).update(project=project)
             else:
                 Event.objects.filter(group=group).update(group=other)
 
-                for obj in MessageFilterValue.objects.filter(group=group):
-                    obj2, created = MessageFilterValue.objects.get_or_create(
+                for obj in GroupTag.objects.filter(group=group):
+                    obj2, created = GroupTag.objects.get_or_create(
                         project=project,
                         group=group,
                         key=obj.key,
@@ -218,8 +222,8 @@ class Project(Model):
                     if not created:
                         obj2.update(times_seen=F('times_seen') + obj.times_seen)
 
-                for obj in MessageCountByMinute.objects.filter(group=group):
-                    obj2, created = MessageCountByMinute.objects.get_or_create(
+                for obj in GroupCountByMinute.objects.filter(group=group):
+                    obj2, created = GroupCountByMinute.objects.get_or_create(
                         project=project,
                         group=group,
                         date=obj.date,
@@ -527,7 +531,7 @@ class Group(EventBase):
         return module, self.data['version']
 
     def get_unique_tags(self, tag):
-        return self.messagefiltervalue_set.filter(
+        return self.grouptag_set.filter(
             key=tag,
         ).values_list(
             'value',
@@ -542,7 +546,7 @@ class Group(EventBase):
 
     def get_tags(self):
         if not hasattr(self, '_tag_cache'):
-            tags = sorted(self.messagefiltervalue_set.values_list('key', flat=True).distinct())
+            tags = sorted(self.grouptag_set.values_list('key', flat=True).distinct())
             self._tag_cache = tags
         return self._tag_cache
 
@@ -625,9 +629,12 @@ class Event(EventBase):
             try:
                 cls = import_string(key)
             except ImportError:
-                pass  # suppress invalid interfaces
+                continue  # suppress invalid interfaces
+
+            value = safe_execute(cls, **data)
+            if not value:
+                continue
 
-            value = cls(**data)
             result.append((key, value))
 
         return SortedDict((k, v) for k, v in sorted(result, key=lambda x: x[1].get_score(), reverse=True))
@@ -706,7 +713,7 @@ class FilterValue(Model):
     __repr__ = sane_repr('project_id', 'key', 'value')
 
 
-class MessageFilterValue(Model):
+class GroupTag(Model):
     """
     Stores the total number of messages seen by a group matching
     the given filter.
@@ -722,6 +729,7 @@ class MessageFilterValue(Model):
     objects = BaseManager()
 
     class Meta:
+        db_table = 'sentry_messagefiltervalue'
         unique_together = (('project', 'key', 'value', 'group'),)
 
     __repr__ = sane_repr('project_id', 'group_id', 'key', 'value')
@@ -729,10 +737,13 @@ class MessageFilterValue(Model):
     def save(self, *args, **kwargs):
         if not self.first_seen:
             self.first_seen = self.last_seen
-        super(MessageFilterValue, self).save(*args, **kwargs)
+        super(GroupTag, self).save(*args, **kwargs)
+
+# Legacy
+MessageFilterValue = GroupTag
 
 
-class MessageCountByMinute(Model):
+class GroupCountByMinute(Model):
     """
     Stores the total number of messages seen by a group at N minute intervals.
 
@@ -749,10 +760,14 @@ class MessageCountByMinute(Model):
     objects = BaseManager()
 
     class Meta:
+        db_table = 'sentry_messagecountbyminute'
         unique_together = (('project', 'group', 'date'),)
 
     __repr__ = sane_repr('project_id', 'group_id', 'date')
 
+# Legacy
+MessageCountByMinute = GroupCountByMinute
+
 
 class ProjectCountByMinute(Model):
     """
@@ -995,8 +1010,8 @@ def create_default_project(created_models, verbosity=2, **kwargs):
             print 'Created internal Sentry project (slug=%s, id=%s)' % (project.slug, project.id)
 
         # Iterate all groups to update their relations
-        for model in (Group, Event, FilterValue, MessageFilterValue,
-                      MessageCountByMinute):
+        for model in (Group, Event, FilterValue, GroupTag,
+                      GroupCountByMinute):
             if verbosity > 0:
                 print ('Backfilling project ids for %s.. ' % model),
             model.objects.filter(project__isnull=True).update(
