@@ -96,7 +96,7 @@ class GroupTransformer(Transformer):
             'level': obj.level,
             'levelName': escape(obj.get_level_display()),
             'logger': escape(obj.logger),
-            'permalink': reverse('sentry-group', args=[obj.project.slug, obj.id]),
+            'permalink': reverse('sentry-group', args=[obj.team.slug, obj.project.slug, obj.id]),
             'versions': list(obj.get_version() or []),
             'lastSeen': obj.last_seen.isoformat(),
             'timeSpent': obj.avg_time_spent,
