@@ -57,6 +57,29 @@ def get_project_list(user=None, access=None, hidden=False, key='id', select_rela
         for p in base_qs.filter(filters).order_by('name'))
 
 
+def group_is_public(group, user):
+    """
+    Return ``True`` if the this group if the user viewing it should see a restricted view.
+
+    This check should be used in combination with project membership checks, as we're only
+    verifying if the user should have a restricted view of something they already have access
+    to.
+    """
+    # if the group isn't public, this check doesnt matter
+    if not group.is_public:
+        return False
+    # anonymous users always are viewing as if it were public
+    if not user.is_authenticated():
+        return True
+    # superusers can always view events
+    if user.is_superuser:
+        return False
+    # project owners can view events
+    if group.project in get_project_list(user).values():
+        return False
+    return True
+
+
 def get_team_list(user, access=None):
     warnings.warn('get_team_list is Deprecated. Use Team.objects.get_for_user instead.', DeprecationWarning)
     return Team.objects.get_for_user(user, access)
@@ -110,8 +133,6 @@ def get_default_context(request, existing_context=None, team=None):
     from sentry.plugins import plugins
 
     context = {
-        'COMPRESS_ENABLED': dj_settings.COMPRESS_ENABLED,
-        'COMPRESS_LESS': dj_settings.COMPRESS_ENABLED and dj_settings.LESS_BIN,
         'HAS_SEARCH': settings.USE_SEARCH,
         'MESSAGES_PER_PAGE': settings.MESSAGES_PER_PAGE,
         'INTERNAL_PROJECT': get_internal_project(),
@@ -134,11 +155,12 @@ def get_default_context(request, existing_context=None, team=None):
 
         if not existing_context or 'PROJECT_LIST' not in existing_context:
             if team:
-                context['PROJECT_LIST'] = Project.objects.filter(team=team)
+                project_list = Project.objects.filter(team=team)
             else:
-                context['PROJECT_LIST'] = get_project_list(request.user).values()
+                project_list = get_project_list(request.user).values()
+            context['PROJECT_LIST'] = sorted(project_list, key=lambda x: x.name)
         if not existing_context or 'TEAM_LIST' not in existing_context:
-            context['TEAM_LIST'] = Team.objects.get_for_user(request.user).values()
+            context['TEAM_LIST'] = sorted(Team.objects.get_for_user(request.user).values(), key=lambda x: x.name)
 
     return context
 
